########################################################################
#
#	License: BSD
#	Created: October 19, 2004
#	Author:  Ivan Vilata i Balaguer - reverse:net.selidor@ivan
#
#	$Source: /home/ivan/_/programari/pytables/svn/cvs/pytables/pytables/tables/nodes/__init__.py,v $
#	$Id: __init__.py 2381 2007-02-16 18:06:40Z ivilata $
#
########################################################################

"""Special node behaviours for PyTables.

This package contains several modules that give specific behaviours
to PyTables nodes.  For instance, the filenode module provides
a file interface to a PyTables node.


Package modules:
	filenode -- A file interface to nodes for PyTables databases.
"""

# Revision for the package initialization code.
__revision__ = '$Id: __init__.py 2381 2007-02-16 18:06:40Z ivilata $'

# The list of names to be exported to the importing module.
__all__ = ['filenode']



## Local Variables:
## mode: python
## py-indent-offset: 4
## tab-width: 4
## End:
